package com.logicbig.example;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;
import javax.persistence.Query;
import java.util.Arrays;
import java.util.List;

public class ExampleMain {

    public static void main(String[] args) {
        EntityManagerFactory emf =
                Persistence.createEntityManagerFactory("example-unit");
        try {
            persistEntities(emf);
            displayEntities(emf);
        } finally {
            emf.close();
        }
    }

    private static Employee persistEntities(EntityManagerFactory emf) {
        System.out.println("-- persisting employee --");
        EntityManager em = emf.createEntityManager();
        Employee employee = new Employee("Sara Dorsey", "Admin");
        em.getTransaction().begin();
        em.persist(employee);
        em.getTransaction().commit();
        em.close();

        print("Employee persisted", employee);
        return employee;
    }

    private static void displayEntities(EntityManagerFactory emf) {
        //loading all entities
        EntityManager em = emf.createEntityManager();
        Query query = em.createQuery("Select e from Employee e");
        List<Employee> list = (List<Employee>) query.getResultList();
        for (Employee employee : list) {
            //sending to ui for display
            displayEntity(employee);
            print("refreshing employee", employee);
            //now refreshing entity before doing something with it
            em.refresh(employee);
            print("after refreshing employee", employee);
        }
    }

    private static void displayEntity(Employee employee) {
        System.out.println("-- displaying employee --");
        System.out.println(employee);
        employee.setDepartment("Sales");
        print("employee modified in displayEntity()", employee);
    }


    private static void print(String msg, Object... objects) {
        System.out.printf("%s: %s%n", msg, Arrays.asList(objects));
    }
}